@@ -29,7 +29,7 @@ from maleo.schemas.security.authentication import OptionalAnyAuthentication
 from maleo.schemas.security.authorization import OptionalAnyAuthorization
 from maleo.schemas.security.impersonation import OptionalImpersonation
 from maleo.types.uuid import OptionalUUID
-from .config import Config
+from .config import ResourceConfig
 from .constants import STATUS_LOG_LEVEL
 from .schemas import CPUUsage, MemoryUsage, Usage, AggregateUsage, Measurement
 from .utils import aggregate_status
@@ -38,7 +38,7 @@ from .utils import aggregate_status
 class ResourceMonitor:
     def __init__(
         self,
-        config: Config,
+        config: ResourceConfig,
         logger: Application[EnvironmentT, ServiceKeyT],
         application_context: OptionalApplicationContext = None,
     ):
